==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/SelectedItemChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SelectedItemChangedEventArgsDescription } from "./SelectedItemChangedEventArgsDescription";
/**
 * @hidden
 */
export let SelectedItemChangedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class SelectedItemChangedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (SelectedItemChangedEventArgsDescriptionMetadata.a == null) {
                SelectedItemChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                SelectedItemChangedEventArgsDescriptionMetadata.c(SelectedItemChangedEventArgsDescriptionMetadata.a);
            }
            if (a.k(SelectedItemChangedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ab(SelectedItemChangedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("OldItem", "Unknown");
            a.item("NewItem", "Unknown");
        }
        static d(a) {
            SelectedItemChangedEventArgsDescriptionMetadata.b(a);
            a.ad("SelectedItemChangedEventArgs", () => new SelectedItemChangedEventArgsDescription());
            a.ac("SelectedItemChangedEventArgs", SelectedItemChangedEventArgsDescriptionMetadata.a);
        }
    }
    SelectedItemChangedEventArgsDescriptionMetadata.$t = markType(SelectedItemChangedEventArgsDescriptionMetadata, 'SelectedItemChangedEventArgsDescriptionMetadata');
    SelectedItemChangedEventArgsDescriptionMetadata.a = null;
    return SelectedItemChangedEventArgsDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/SelectedItemChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SelectedItemChangedEventArgsDescription } from "./SelectedItemChangedEventArgsDescription";
/**
 * @hidden
 */
export let SelectedItemChangedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class SelectedItemChangedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (SelectedItemChangedEventArgsDescriptionMetadata.a == null) {
                SelectedItemChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                SelectedItemChangedEventArgsDescriptionMetadata.c(SelectedItemChangedEventArgsDescriptionMetadata.a);
            }
            if (a.k(SelectedItemChangedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(SelectedItemChangedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("OldItem", "Unknown");
            a.item("NewItem", "Unknown");
        }
        static d(a) {
            SelectedItemChangedEventArgsDescriptionMetadata.b(a);
            a.ae("SelectedItemChangedEventArgs", () => new SelectedItemChangedEventArgsDescription());
            a.ad("SelectedItemChangedEventArgs", SelectedItemChangedEventArgsDescriptionMetadata.a);
        }
    }
    SelectedItemChangedEventArgsDescriptionMetadata.$t = markType(SelectedItemChangedEventArgsDescriptionMetadata, 'SelectedItemChangedEventArgsDescriptionMetadata');
    SelectedItemChangedEventArgsDescriptionMetadata.a = null;
    return SelectedItemChangedEventArgsDescriptionMetadata;
})();
